@@ -4,6 +4,8 @@ Description: Omit
 LastEditors: Rustle Karl
 LastEditTime: 2022.02.05 20:22
 """
+from enum import Enum
+
 from .render import render_templates
 
 
@@ -17,14 +19,25 @@ def c():
     )
 
 
-def qt5(console: bool = False):
+class Qt5Templates(str, Enum):
+    Console = ".console"
+    Gui = ".gui"
+    Qml = ".qml"
+
+
+def qt5(template=Qt5Templates.Gui):
     render_templates(
         "qt5",
-        include_suffixes=[".console"] if console else [".gui"],
+        include_suffixes=[template],
         folders=[
+            "assets",
+            "assets/fonts",
+            "assets/images",
             "cmake-build-debug",
+            "cmake-build-release",
             "include",
             "lib",
         ],
         common=False,
+        template=template,
     )
