@@ -5,11 +5,12 @@ LastEditors: Rustle Karl
 LastEditTime: 2022.02.02 18:14
 """
 import os
+import shutil
 
 import click
 from click_aliases import ClickAliasedGroup
 
-from .c import c as _c, qt5 as _qt5
+from .c import Qt5Templates, c as _c, qt5 as _qt5
 from .common import create_common_files
 from .golang import GoCombinations, golang as _golang
 from .notes import notes as _notes
@@ -31,6 +32,11 @@ def base():
     help="Remove all example files for release.",
 )
 def clean():
+    build_dirs = {
+        "cmake-build-debug",  # Clion cmake build
+        "cmake-build-release",  # Makefile cmake build
+    }
+
     for root, dirs, files in os.walk("."):
         for f in files:
             if f.find("example") != -1:
@@ -44,6 +50,12 @@ def clean():
                 click.echo(f"clean {d}")
                 os.rmdir(d)
 
+            elif d in build_dirs:
+                d = os.path.join(root, d)
+                click.echo(f"clean {d}")
+                shutil.rmtree(d)
+                os.mkdir(d)
+
 
 @command_cps.command(
     aliases=["py"],
@@ -81,10 +93,11 @@ def c():
 
 @command_cps.command(help="Create Qt5 project scaffold.")
 @click.option(
-    "--console/--gui",
-    "-c/-g",
-    default=False,
+    "--template",
+    "-t",
+    type=click.Choice(Qt5Templates),
+    default=Qt5Templates.Gui,
     help="Read only or create configuration files.",
 )
-def qt5(console):
-    _qt5(console)
+def qt5(template=Qt5Templates.Gui):
+    _qt5(template)
